'use client';
import Image from 'next/image';
import React, { createContext, useContext, useState } from 'react';
import type { ReactNode } from 'react';
import { useAuth } from '@/components/context';
import { Button, type buttonVariants } from '@/components/ui';
import { type ComponentProps } from 'react';
import { type VariantProps } from 'class-variance-authority';

type TVModeContextProps = {
  tvMode: boolean;
  toggleTVMode: () => void;
};

type TVToggleProps = {
  className?: ComponentProps<'button'>['className'];
  buttonSize?: VariantProps<typeof buttonVariants>['size'];
  buttonVariant?: VariantProps<typeof buttonVariants>['variant'];
  imageWidth?: number;
  imageHeight?: number;
};

const TVModeContext = createContext<TVModeContextProps | undefined>(undefined);

export const TVModeProvider = ({ children }: { children: ReactNode }) => {
  const [tvMode, setTVMode] = useState(false);
  const toggleTVMode = () => {
    setTVMode((prev) => !prev);
  };
  return (
    <TVModeContext.Provider value={{ tvMode, toggleTVMode }}>
      {children}
    </TVModeContext.Provider>
  );
};

export const useTVMode = () => {
  const context = useContext(TVModeContext);
  if (!context) {
    throw new Error('useTVMode must be used within a TVModeProvider');
  }
  return context;
};

export const TVToggle = ({
  className = 'my-auto cursor-pointer',
  buttonSize = 'default',
  buttonVariant = 'link',
  imageWidth = 25,
  imageHeight = 25,
}: TVToggleProps) => {
  const { tvMode, toggleTVMode } = useTVMode();
  const { isAuthenticated } = useAuth();
  if (!isAuthenticated) return <div />;
  return (
    <Button
      onClick={toggleTVMode}
      className={className}
      size={buttonSize}
      variant={buttonVariant}
    >
      {tvMode ? (
        <Image
          src='/icons/tv/exit.svg'
          alt='Exit TV Mode'
          width={imageWidth}
          height={imageHeight}
        />
      ) : (
        <Image
          src='/icons/tv/enter.svg'
          alt='Exit TV Mode'
          width={imageWidth}
          height={imageHeight}
        />
      )}
    </Button>
  );
};
